package s2dao.id.valuetype.test.type;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import org.seasar.extension.jdbc.types.AbstractValueType;

import s2dao.id.valuetype.test.entity.Identity;

public class IdentityType extends AbstractValueType
{
    public IdentityType()
    {
        super( Types.BIGINT );
    }

    /**
     * @see org.seasar.extension.jdbc.ValueType#bindValue(java.sql.PreparedStatement, int, java.lang.Object)
     */
    @Override
    public void bindValue( PreparedStatement ps, int index, Object value ) throws SQLException
    {
        if( value == null )
        {
            setNull( ps, index );
        }
        else
        {
            ps.setLong( index, ( (Identity)value ).getId().longValue() );
        }
    }

    /**
     * @see org.seasar.extension.jdbc.ValueType#bindValue(java.sql.CallableStatement, java.lang.String, java.lang.Object)
     */
    @Override
    public void bindValue( CallableStatement cs, String parameterName, Object value ) throws SQLException
    {
        if( value == null )
        {
            setNull( cs, parameterName );
        }
        else
        {
            cs.setLong( parameterName, ( (Identity)value ).getId().longValue() );
        }
    }

    /**
     * @see org.seasar.extension.jdbc.ValueType#getValue(java.sql.ResultSet, int)
     */
    @Override
    public Object getValue( ResultSet resultSet, int index ) throws SQLException
    {
        Long id = (Long)resultSet.getObject( index );
        if( id == null )
        {
            return null;
        }
        Identity identity = new Identity();
        identity.setId( id );
        return identity;
    }

    /**
     * @see org.seasar.extension.jdbc.ValueType#getValue(java.sql.ResultSet, java.lang.String)
     */
    @Override
    public Object getValue( ResultSet resultSet, String columnName ) throws SQLException
    {
        Long id = (Long)resultSet.getObject( columnName );
        if( id == null )
        {
            return null;
        }
        Identity identity = new Identity();
        identity.setId( id );
        return identity;
    }

    /**
     * @see org.seasar.extension.jdbc.ValueType#getValue(java.sql.CallableStatement, int)
     */
    @Override
    public Object getValue( CallableStatement cs, int index ) throws SQLException
    {
        Long id = (Long)cs.getObject( index );
        if( id == null )
        {
            return null;
        }
        Identity identity = new Identity();
        identity.setId( id );
        return identity;
    }

    /**
     * @see org.seasar.extension.jdbc.ValueType#getValue(java.sql.CallableStatement, java.lang.String)
     */
    @Override
    public Object getValue( CallableStatement cs, String parameterName ) throws SQLException
    {
        Long id = (Long)cs.getObject( parameterName );
        if( id == null )
        {
            return null;
        }
        Identity identity = new Identity();
        identity.setId( id );
        return identity;
    }

    /**
     * @see org.seasar.extension.jdbc.ValueType#toText(java.lang.Object)
     */
    @Override
    public String toText( Object value )
    {
        return ( value == null ) ? null : value.toString();
    }
}
